package cc.fascinated.bat.features.minecraft.command.serverwatcher;

import cc.fascinated.bat.command.BatCommand;
import cc.fascinated.bat.command.CommandInfo;
import cc.fascinated.bat.common.EmbedDescriptionBuilder;
import cc.fascinated.bat.common.EmbedUtils;
import cc.fascinated.bat.common.EnumUtils;
import cc.fascinated.bat.features.minecraft.MinecraftProfile;
import cc.fascinated.bat.features.minecraft.ServerWatcher;
import cc.fascinated.bat.model.BatGuild;
import cc.fascinated.bat.model.BatUser;
import lombok.NonNull;
import net.dv8tion.jda.api.entities.Member;
import net.dv8tion.jda.api.entities.channel.middleman.MessageChannel;
import net.dv8tion.jda.api.interactions.commands.SlashCommandInteraction;
import org.springframework.stereotype.Component;
import xyz.mcutils.models.server.ServerPlatform;

/**
 * @author Fascinated (fascinated7)
 */
@Component("minecraft-server-watcher.list:sub")
@CommandInfo(
        name = "list",
        description = "Shows a list of all the servers being watched"
)
public class ListSubCommand extends BatCommand {
    @Override
    public void execute(BatGuild guild, @NonNull BatUser user, @NonNull MessageChannel channel, Member member, @NonNull SlashCommandInteraction event) {
        MinecraftProfile profile = guild.getMinecraftProfile();

        EmbedDescriptionBuilder description = new EmbedDescriptionBuilder("Server Watcher");
        description.appendLine("Here is a list of all the servers being watched", false);
        description.emptyLine();
        for (ServerWatcher server : profile.getServerWatchers()) {
            int platformDefaultPort = server.getPlatform() == ServerPlatform.JAVA ? 25565 : 19132;
            String hostname = server.getHostname() + (server.getPort() != platformDefaultPort ? ":" + server.getPort() : "");

            description.appendLine("`%s` (%s) - %s".formatted(
                    hostname,
                    EnumUtils.getEnumName(server.getPlatform()),
                    server.getChannel().getAsMention()
            ), true);
        }

        event.replyEmbeds(EmbedUtils.successEmbed()
                .setDescription(description.build())
                .build()).queue();
    }
}
